import React, { createElement } from "react";
import clsx from "clsx";
import SortableHeaderCell from "./headerCells/SortableHeaderCell";
import ResizableHeaderCell from "./headerCells/ResizableHeaderCell";
function getAriaSort(sortDirection) {
    switch (sortDirection) {
        case "ASC":
            return "ascending";
        case "DESC":
            return "descending";
        default:
            return "none";
    }
}
export default function SuperHeaderCell({ column, onResize, index, left, superSpecs: superSpecs, allRowsSelected, onAllRowsSelectionChange, sortColumn, sortDirection, onSort, }) {
    function getCell() {
        //giving the priority for the value instead of the name
        if (!column.headerRenderer && superSpecs.value != undefined)
            return superSpecs.value;
        if (!column.headerRenderer)
            return superSpecs.name;
        return createElement(column.headerRenderer, {
            column,
            allRowsSelected,
            onAllRowsSelectionChange,
        });
    }
    let cell = getCell();
    if (column.sortable) {
        cell = (React.createElement(SortableHeaderCell, { column: column, onSort: onSort, sortColumn: sortColumn, sortDirection: sortDirection }, cell));
    }
    const className = clsx("rdg-cell", column.headerCellClass, {
        "rdg-cell-frozen": column.frozen,
        "rdg-cell-frozen-last": column.isLastFrozenColumn,
    });
    const style = {
        width: column.width * superSpecs.span,
        left: left,
        textAlign: superSpecs ? superSpecs.textAlign : "center",
    };
    cell = (React.createElement("div", { role: "column-header", "aria-colindex": index + 1, "aria-sort": sortColumn === superSpecs.name ? getAriaSort(sortDirection) : undefined, className: className, style: style }, cell));
    if (column.resizable) {
        cell = (React.createElement(ResizableHeaderCell, { column: column, onResize: onResize }, cell));
    }
    return cell;
}
//# sourceMappingURL=SuperHeaderCell.js.map